@@ -15,6 +15,7 @@
 from google.adk.tools import load_memory
 
 from veadk import Agent
+from veadk.consts import DEFAULT_MODEL_EXTRA_HEADERS
 from veadk.knowledgebase import KnowledgeBase
 from veadk.memory.long_term_memory import LongTermMemory
 from veadk.tools import load_knowledgebase_tool
@@ -26,11 +27,14 @@ def test_agent():
     long_term_memory = LongTermMemory(backend="local")
     tracer = OpentelemetryTracer()
 
+    model_extra_headers = {"test-header": "test-value"}
+
     agent = Agent(
         model_name="test_model_name",
         model_provider="test_model_provider",
         model_api_key="test_model_api_key",
         model_api_base="test_model_api_base",
+        model_extra_headers=model_extra_headers,
         tools=[],
         sub_agents=[],
         knowledgebase=knowledgebase,
@@ -39,7 +43,10 @@ def test_agent():
         serve_url="",
     )
 
+    model_extra_headers |= DEFAULT_MODEL_EXTRA_HEADERS
+
     assert agent.model.model == f"{agent.model_provider}/{agent.model_name}"
+    assert agent.model_extra_headers == model_extra_headers
 
     assert agent.knowledgebase == knowledgebase
     assert agent.knowledgebase.backend == "local"
