@@ -28,9 +28,10 @@ from typing_extensions import Any
 
 from veadk.config import getenv
 from veadk.consts import (
-    DEFALUT_MODEL_AGENT_PROVIDER,
+    DEFAULT_MODEL_AGENT_PROVIDER,
     DEFAULT_MODEL_AGENT_API_BASE,
     DEFAULT_MODEL_AGENT_NAME,
+    DEFAULT_MODEL_EXTRA_HEADERS,
 )
 from veadk.evaluation import EvalSetRecorder
 from veadk.knowledgebase import KnowledgeBase
@@ -40,6 +41,7 @@ from veadk.prompts.agent_default_prompt import DEFAULT_DESCRIPTION, DEFAULT_INST
 from veadk.tracing.base_tracer import BaseTracer
 from veadk.utils.logger import get_logger
 from veadk.utils.patches import patch_asyncio
+from veadk.version import VERSION
 
 patch_asyncio()
 logger = get_logger(__name__)
@@ -60,11 +62,10 @@ class Agent(LlmAgent):
     instruction: str = DEFAULT_INSTRUCTION
     """The instruction for the agent, such as principles of function calling."""
 
-    # factory
     model_name: str = getenv("MODEL_AGENT_NAME", DEFAULT_MODEL_AGENT_NAME)
     """The name of the model for agent running."""
 
-    model_provider: str = getenv("MODEL_AGENT_PROVIDER", DEFALUT_MODEL_AGENT_PROVIDER)
+    model_provider: str = getenv("MODEL_AGENT_PROVIDER", DEFAULT_MODEL_AGENT_PROVIDER)
     """The provider of the model for agent running."""
 
     model_api_base: str = getenv("MODEL_AGENT_API_BASE", DEFAULT_MODEL_AGENT_API_BASE)
@@ -73,6 +74,9 @@ class Agent(LlmAgent):
     model_api_key: str = Field(default_factory=lambda: getenv("MODEL_AGENT_API_KEY"))
     """The api key of the model for agent running."""
 
+    model_extra_config: dict = Field(default_factory=dict)
+    """The extra config to include in the model requests."""
+
     tools: list[ToolUnion] = []
     """The tools provided to agent."""
 
@@ -96,11 +100,27 @@ class Agent(LlmAgent):
 
     def model_post_init(self, __context: Any) -> None:
         super().model_post_init(None)  # for sub_agents init
-        self.model = LiteLlm(
-            model=f"{self.model_provider}/{self.model_name}",
-            api_key=self.model_api_key,
-            api_base=self.model_api_base,
-        )
+
+        # add model request source (veadk) in extra headers
+        if self.model_extra_config and "extra_headers" in self.model_extra_config:
+            self.model_extra_config["extra_headers"] |= DEFAULT_MODEL_EXTRA_HEADERS
+        else:
+            self.model_extra_config["extra_headers"] = DEFAULT_MODEL_EXTRA_HEADERS
+
+        if not self.model:
+            self.model = LiteLlm(
+                model=f"{self.model_provider}/{self.model_name}",
+                api_key=self.model_api_key,
+                api_base=self.model_api_base,
+                **self.model_extra_config,
+            )
+            logger.debug(
+                f"LiteLLM client created with config: {self.model_extra_config}"
+            )
+        else:
+            logger.warning(
+                "You are trying to use your own LiteLLM client, some default request headers may be missing."
+            )
 
         if self.knowledgebase:
             from veadk.tools import load_knowledgebase_tool
@@ -113,18 +133,11 @@ class Agent(LlmAgent):
 
             self.tools.append(load_memory)
 
-        if self.tracers:
-            self.before_model_callback = []
-            self.after_model_callback = []
-            self.after_tool_callback = []
-            for tracer in self.tracers:
-                self.before_model_callback.append(tracer.tracer_hook_before_model)
-                self.after_model_callback.append(tracer.tracer_hook_after_model)
-                self.after_tool_callback.append(tracer.tracer_hook_after_tool)
+        logger.info(f"VeADK version: {VERSION}")
 
-        logger.info(f"Agent `{self.name}` init done.")
+        logger.info(f"{self.__class__.__name__} `{self.name}` init done.")
         logger.debug(
-            f"Agent: {self.model_dump(include={'name', 'model_name', 'model_api_base', 'tools', 'serve_url'})}"
+            f"Agent: {self.model_dump(include={'name', 'model_name', 'model_api_base', 'tools'})}"
         )
 
     async def _run(
@@ -221,9 +234,6 @@ class Agent(LlmAgent):
             session_service=session_service,
             memory_service=self.long_term_memory,
         )
-        if getattr(self, "tracers", None):
-            for tracer in self.tracers:
-                tracer.set_app_name(app_name)
 
         logger.info(f"Begin to process prompt {prompt}")
         # run
